@@ -16,7 +16,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""Convert OpenDocument (ODF) files to XLIFF localization files.
+"""
+Convert OpenDocument (ODF) files to XLIFF localization files.
 
 See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/commands/odf2xliff.html
 for examples and usage instructions.
@@ -27,18 +28,16 @@ from io import BytesIO
 from translate.convert import convert
 from translate.storage import factory
 from translate.storage.odf_io import open_odf
-from translate.storage.odf_shared import (inline_elements,
-                                          no_translate_content_elements)
+from translate.storage.odf_shared import inline_elements, no_translate_content_elements
 from translate.storage.xml_extract.extract import ParseState, build_store
 
 
 def convertodf(inputfile, outputfile, templates):
     """Convert an ODF package to XLIFF."""
-
     store = factory.getobject(outputfile)
 
     try:
-        store.setfilename(store.getfilenode('NoName'), inputfile.name)
+        store.setfilename(store.getfilenode("NoName"), inputfile.name)
     except Exception:
         print("couldn't set origin filename")
 
@@ -93,5 +92,5 @@ def main(argv=None):
     parser.run(argv)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
