@@ -16,7 +16,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""Convert Gettext PO localization files to Symbian translation files.
+"""
+Convert Gettext PO localization files to Symbian translation files.
 
 See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/commands/symb2po.html
 for examples and usage instructions.
