@@ -17,7 +17,8 @@
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
 
-"""Convert web2py translation dictionaries (.py) to GNU/gettext PO files.
+"""
+Convert web2py translation dictionaries (.py) to GNU/gettext PO files.
 
 See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/commands/web2py2po.html
 for examples and usage instructions.
@@ -44,7 +45,7 @@ class web2py2po:
         targetheader = self.mypofile.header()
         targetheader.addnote("extracted from web2py", "developer")
 
-        for source_str in mydict.keys():
+        for source_str in mydict:
             target_str = mydict[source_str]
             if target_str == source_str.replace("@markmin\x01", ""):
                 # a convention with new (untranslated) web2py files
