@@ -16,9 +16,10 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents the Azerbaijani language.
+"""
+This module represents the Azerbaijani language.
 
-.. seealso:: http://en.wikipedia.org/wiki/Azerbaijani_language
+.. seealso:: :wp:`Azerbaijani_language`
 """
 
 
