@@ -16,8 +16,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents the Finnish language.
-"""
+"""This module represents the Finnish language."""
 
 
 from translate.lang import common
@@ -26,8 +25,4 @@ from translate.lang import common
 class fi(common.Common):
     """This class represents Finnish."""
 
-    validaccel = ("abcdefghijklmnopqrstuvwxyz"
-                  "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
-                  "1234567890"
-                  "äö"
-                  "ÄÖ")
+    validaccel = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890äöÄÖ"
