@@ -16,9 +16,10 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents the Sicilian language.
+"""
+This module represents the Sicilian language.
 
-.. seealso:: http://en.wikipedia.org/wiki/Sicilian_language
+.. seealso:: :wp:`Sicilian_language`
 """
 
 
@@ -28,16 +29,14 @@ from translate.lang import common
 
 
 def contains_illegal(illegal_substrings, string):
-    """Check if string contains any of the specified illegal substrings.
+    """
+    Check if string contains any of the specified illegal substrings.
 
     :param illegal_substrings: an iterable of illegal substrings
     :param string: the string to check against occurences of illegal substrings
     :return: True if string contains any of the illegal substrings
     """
-    for s in illegal_substrings:
-        if s in string:
-            return True
-    return False
+    return any(s in string for s in illegal_substrings)
 
 
 sicilianconfig = CheckerConfig(
@@ -46,10 +45,10 @@ sicilianconfig = CheckerConfig(
 
 
 class SicilianChecker(TranslationChecker):
-    """A Checker class for Sicilian"""
+    """A Checker class for Sicilian."""
 
     def __init__(self, **kwargs):
-        checkerconfig = kwargs.get("checkerconfig", None)
+        checkerconfig = kwargs.get("checkerconfig")
 
         if checkerconfig is None:
             checkerconfig = CheckerConfig()
@@ -60,7 +59,8 @@ class SicilianChecker(TranslationChecker):
 
     @critical
     def italianisms(self, str1, str2):
-        """Check if the translation contains common errors done by italophones.
+        """
+        Check if the translation contains common errors done by italophones.
 
         Mainly inspired by musttranslatewords(), but with a different logic: return True if
         the given word appears in the translation but not in the source (if it's in the source,
@@ -90,7 +90,7 @@ class SicilianChecker(TranslationChecker):
         stopwords = [
             f"{word} ({errors[word]})"
             for word in words2
-            if word.lower() in errors.keys() and word not in words1
+            if word.lower() in errors and word not in words1
         ]
 
         if stopwords:
@@ -100,7 +100,10 @@ class SicilianChecker(TranslationChecker):
 
     @critical
     def vocalism(self, str1, str2):
-        """Check correct word-endings. All words should end with a/i/u, but a handful of exceptions:
+        """
+        Check correct word-endings.
+
+        All words should end with a/i/u, but a handful of exceptions:
 
           - me, to, so (possessive pronouns)
           - po (verb "putiri")
@@ -118,9 +121,14 @@ class SicilianChecker(TranslationChecker):
         stopwords = []
 
         for word in self.config.lang.words(str2):
-            if word not in str1 and word.lower() not in exceptions:
-                if word.lower().endswith(("e", "o")) and word.lower() not in stopwords:
-                    stopwords.append(word.lower())
+            lower_word = word.lower()
+            if (
+                word not in str1
+                and lower_word not in exceptions
+                and lower_word.endswith(("e", "o"))
+                and lower_word not in stopwords
+            ):
+                stopwords.append(lower_word)
 
         if stopwords:
             raise FilterFailure("Please respect vocalism: %s" % (", ".join(stopwords)))
@@ -128,7 +136,8 @@ class SicilianChecker(TranslationChecker):
 
     @critical
     def suffixes(self, str1, str2):
-        """Check for common word suffixes to be written correctly.
+        """
+        Check for common word suffixes to be written correctly.
 
         :param str1: the source string
         :param str2: the target (translated) string
@@ -138,12 +147,12 @@ class SicilianChecker(TranslationChecker):
             "zzioni": "zziuni",
         }
 
-        stopwords = []
-
-        for word in self.config.lang.words(str2):
-            for suffix in suffixes.keys():
-                if word not in str1 and word.lower().endswith(suffix):
-                    stopwords.append(f"{word} (-{suffixes[suffix]})")
+        stopwords = [
+            f"{word} (-{suffixes[suffix]})"
+            for word in self.config.lang.words(str2)
+            for suffix in suffixes
+            if word not in str1 and word.lower().endswith(suffix)
+        ]
 
         if stopwords:
             raise FilterFailure(
