@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2009 Zuza Software Foundation
 #
@@ -17,10 +16,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents the Southern Sotho language.
-"""
+"""This module represents the Southern Sotho language."""
 
-from __future__ import unicode_literals
 
 from translate.lang import common
 
