@@ -16,9 +16,10 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents the Urdu language.
+"""
+This module represents the Urdu language.
 
-.. seealso:: http://en.wikipedia.org/wiki/Urdu_language
+.. seealso:: :wp:`Urdu_language`
 """
 
 
@@ -35,10 +36,10 @@ class ur(common.Common):
         ",": "،",
         ";": "؛",
         "?": "؟",
-        #This causes problems with variables, so commented out for now:
-        #"%": "٪",
+        # This causes problems with variables, so commented out for now:
+        # "%": "٪",
     }
 
     ignoretests = {
-        'all': ["simplecaps", "startcaps"],
+        "all": ["simplecaps", "startcaps"],
     }
