@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2013 Zuza Software Foundation
 #
@@ -17,12 +16,12 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents the Venda language.
+"""
+This module represents the Venda language.
 
-.. seealso:: http://en.wikipedia.org/wiki/Venda_language
+.. seealso:: :wp:`Venda_language`
 """
 
-from __future__ import unicode_literals
 
 from translate.lang import common
 
