@@ -16,20 +16,46 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""Py2exe can't find stuff that we import dynamically, so we have this file
+"""
+Py2exe can't find stuff that we import dynamically, so we have this file
 just for the sake of the Windows installer to easily pick up all the stuff that
 we need and ensure they make it into the installer.
 """
 
-from . import (catkeys, csvl10n, mo, omegat, po, qm, qph, tbx, tmx, ts2, utx,
-               wordfast, xliff)
+import contextlib
 
+from . import (
+    catkeys,
+    csvl10n,
+    mo,
+    omegat,
+    po,
+    qm,
+    qph,
+    tbx,
+    tmx,
+    ts2,
+    utx,
+    wordfast,
+    xliff,
+)
 
-try:
+with contextlib.suppress(ImportError):
     from . import trados
-except ImportError:
-    pass
 
 __all__ = [
-    "catkeys", "csvl10n", "mo", "omegat", "po", "qm", "qph", "tbx", "tmx", "ts2", "utx", "wordfast", "xliff", "trados"
+    "catkeys",
+    "csvl10n",
+    "mo",
+    "omegat",
+    "po",
+    "qm",
+    "qph",
+    "tbx",
+    "tmx",
+    "ts2",
+    "utx",
+    "wordfast",
+    "xliff",
+    "trados",
 ]
